Learn R Programming

bgw (version 0.1.4)

bgw-internal: Internal BGW Functions

Description

Internal BGW functions

Arguments

Value

These functions are wrappers for 'Fortran' routines, and are not meant to be called by the user.

Details

These are not to be called by the user.