An r wrapper to call drglg_c, which in turn is a wrapper to call the Fortran subroutine drglg. drglg is the BGW iteration driver for performing statistical parameter estimation
bgw_drglg(
d,
dr,
iv,
liv,
lv,
n,
nd,
nn,
p,
ps,
r,
rd,
v,
x,
rhoi,
rhor,
i_itsum
)out List of return values.
Scaling vector
Derivative of the choice probability model wrt x
BGW internal vector of integer values
Length of iv.
Length of v.
Dimension of vector (r) of generalized residuals for the model
Leading dimension dr. Must be at least ps.
Leading dimension of r, rd
Dimension of x (as well as d, g) = number of parameters being estimated
Number of non-nuisance parameters (= p in this implementation)
Vector of generalized residuals for the model
Vector of storage space for regression diagonostics (not currently used)
BGW internal vector of numeric values
Parameter vector for which the objective function is being minimized
Vector of integers for use by user (not currently used)
Vector of numeric values for use by user (not currently used)
Variable for passing itsum instruction back to bgw_mle