Prints iteration summary, info on initial and final x.
bgw_itsum(d, g, iv, v, x, p, betaIsNamed, betaNames = NULL, i_itsum)iv There are iv values changed inside bgw_itsum. The iv vector is the integer workspace for Fortran BGW.
Scaling vector
Gradient of objective function (negative-log-likelihood) wrt x
BGW internal vector of integer values
BGW internal vector of numeric values
Parameter vector for which the objective function is being minimized
Dimension of x
Logical.
Character vector. If available, has beta parameter names.
Code from caller to select specific options